@@ -4,11 +4,7 @@ from typing import Collection, Iterable, List, Mapping, Optional, Union, Iterato
 from typing import Any, Callable, MutableSequence, Generator
 
 from tabulate import tabulate
-from tinytim.functional.filter import filter_by_indexes, filter_list_by_indexes, indexes_from_filter
-import tinytim.functional.table as func
-import tinytim.functional.inplace as ip
-from tinytim.functional.group import count_data, groupby, sum_data
-from tinytim.functional.utils import all_bool, slice_to_range
+import tinytim.functions as tim
 
 import tinytable.datatypes as dt
 import tinytable.column as column
@@ -38,12 +34,12 @@ class Table:
     def _store_column(self, column_name: str, values: Iterable, inplace=True) -> Union[None, Table]:
         values = list(values)
         if inplace:
-            ip.edit_column(self.data, column_name, values)
+            tim.edit_column(self.data, column_name, values)
         else:
-            return Table(func.edit_column(self.data, column_name, values))
+            return Table(tim.edit_column(self.data, column_name, values))
         
     def __len__(self) -> int:
-        return func.row_count(self.data)
+        return tim.row_count(self.data)
         
     def __repr__(self) -> str:
         index = True if self.labels is None else self.labels
@@ -74,9 +70,9 @@ class Table:
         # tbl[1:4] -> Table
         if isinstance(key, slice):
             validate_int_slice(key)
-            return self.filter_by_indexes(list(slice_to_range(key, len(self))))
+            return self.filter_by_indexes(list(tim.slice_to_range(key, len(self))))
         if isinstance(key, list):
-            if all_bool(key):
+            if tim.all_bool(key):
                 # tbl[[True, False, True, True]] -> Table
                 return self.filter(key)
             # tbl[['id', 'name']] -> Table
@@ -116,16 +112,16 @@ class Table:
 
     @property
     def shape(self) -> tuple[int, int]:
-        return func.shape(self.data)
+        return tim.shape(self.data)
 
     @property
     def size(self) -> int:
-        return func.size(self.data)
+        return tim.size(self.data)
 
     @property
     def columns(self) -> tuple[str]:
         """Column names."""
-        return func.column_names(self.data)
+        return tim.column_names(self.data)
 
     @columns.setter
     def columns(self, values: MutableSequence) -> None:
@@ -134,19 +130,19 @@ class Table:
 
     @property
     def index(self) -> column.Column:
-        return column.Column(func.index(self.data), None, self, self.labels)
+        return column.Column(tim.index(self.data), None, self, self.labels)
 
     @property
     def values(self) -> tuple[tuple]:
-        return func.values(self.data)
+        return tim.values(self.data)
 
     def filter(self, f: Filter) -> Table:
-        indexes = indexes_from_filter(f)
+        indexes = tim.indexes_from_filter(f)
         return self.filter_by_indexes(indexes)
 
     def only_columns(self, column_names: MutableSequence[str]) -> Table:
         """Return new Table with only column_names Columns."""
-        d = func.only_columns(self.data, column_names)
+        d = tim.only_columns(self.data, column_names)
         return Table(d, self.labels)
 
     def _convert_index(self, index: int) -> int:
@@ -177,23 +173,23 @@ class Table:
    
     def row(self, index: int) -> row.Row:
         label = self._get_label(index)
-        return row.Row(func.row_dict(self.data, index), index, self, label)
+        return row.Row(tim.row_dict(self.data, index), index, self, label)
 
     def column(self, column_name: str) -> column.Column:
-        return column.Column(func.column_values(self.data, column_name), column_name, self, self.labels)
+        return column.Column(tim.column_values(self.data, column_name), column_name, self, self.labels)
 
     def drop_column(self, column_name: str, inplace=True) -> Union[None, Table]:
         if inplace:
-            ip.drop_column(self.data, column_name)
+            tim.drop_column_inplace(self.data, column_name)
         else:
-            return Table(func.drop_column(self.data, column_name), self.labels)
+            return Table(tim.drop_column(self.data, column_name), self.labels)
 
     def drop_row(self, index: int, inplace=True) -> Union[None, Table]:
         if inplace:
-            ip.drop_row(self.data, index)
-            ip.drop_label(self.labels, index)
+            tim.drop_row_inplace(self.data, index)
+            tim.drop_label_inplace(self.labels, index)
         else:
-            return Table(func.drop_row(self.data, index), func.drop_label(self.labels, index))
+            return Table(tim.drop_row(self.data, index), tim.drop_label(self.labels, index))
 
     def keys(self) -> tuple[str]:
         return self.columns
@@ -208,19 +204,19 @@ class Table:
         return column.iteritems(self.data, self)
 
     def itertuples(self) -> Generator[tuple, None, None]:
-        return func.itertuples(self.data)
+        return tim.itertuples(self.data)
     
     def edit_row(self, index: int, values: Union[Mapping, MutableSequence], inplace=True) -> Union[None, Table]:
         if inplace:
             if isinstance(values, Mapping):
-                ip.edit_row_items(self.data, index, values)
+                tim.edit_row_items_inplace(self.data, index, values)
             elif isinstance(values, MutableSequence):
-                ip.edit_row_values(self.data, index, values)
+                tim.edit_row_values_inplace(self.data, index, values)
         else:
             if isinstance(values, Mapping):
-                data = func.edit_row_items(self.data, index, values)
+                data = tim.edit_row_items(self.data, index, values)
             elif isinstance(values, MutableSequence):
-                data = func.edit_row_values(self.data, index, values)
+                data = tim.edit_row_values(self.data, index, values)
             return Table(data, copy.copy(self.labels))
             
     def edit_column(self, column_name: str, values: MutableSequence, inplace=True) ->Union[None, Table]:
@@ -228,14 +224,14 @@ class Table:
 
     def edit_value(self, column_name: str, index: int, value: Any, inplace=True) -> Union[None, Table]:
         if inplace:
-            ip.edit_value(self.data, column_name, index, value)
+            tim.edit_value_inplace(self.data, column_name, index, value)
         else:
-            return Table(func.edit_value(self.data, column_name, index, value), copy.copy(self.labels))
+            return Table(tim.edit_value(self.data, column_name, index, value), copy.copy(self.labels))
 
     def copy(self, deep=False) -> Table:
         if deep:
-             return Table(func.deepcopy_table(self.data), copy.deepcopy(self.labels))
-        return Table(func.copy_table(self.data), copy.copy(self.labels))
+             return Table(tim.deepcopy_table(self.data), copy.deepcopy(self.labels))
+        return Table(tim.copy_table(self.data), copy.copy(self.labels))
 
     def cast_column_as(self, column_name: str, data_type: Callable) -> None:
         self.data[column_name] = [data_type(value) for value in self.data[column_name]]
@@ -267,36 +263,36 @@ class Table:
         return None if self.labels is None else self.labels[5:]
 
     def head(self, n: int = 5) -> Table:
-        return Table(func.head(self.data, n), self.label_head(n))
+        return Table(tim.head(self.data, n), self.label_head(n))
 
     def tail(self, n: int = 5) -> Table:
-        return Table(func.tail(self.data, n), self.label_tail(n))
+        return Table(tim.tail(self.data, n), self.label_tail(n))
 
     def nunique(self) -> dict[str, int]:
         """Count number of distinct values in each column.
            Return dict with number of distinct values.
         """
-        return func.nunique(self.data)
+        return tim.nunique(self.data)
 
     def filter_by_indexes(self, indexes: MutableSequence[int]) -> Table:
         """return only rows in indexes"""
-        labels = None if self.labels is None else filter_list_by_indexes(self.labels, indexes)
-        return Table(filter_by_indexes(self.data, indexes), labels=labels)
+        labels = None if self.labels is None else tim.filter_list_by_indexes(self.labels, indexes)
+        return Table(tim.filter_by_indexes(self.data, indexes), labels=labels)
 
     def sample(self, n, random_state=None) -> Table:
         """return random sample of rows"""
-        indexes = func.sample_indexes(self.data, n, random_state)
-        labels = None if self.labels is None else filter_list_by_indexes(self.labels, indexes)
-        return Table(filter_by_indexes(self.data, indexes), labels=labels)
+        indexes = tim.sample_indexes(self.data, n, random_state)
+        labels = None if self.labels is None else tim.filter_list_by_indexes(self.labels, indexes)
+        return Table(tim.filter_by_indexes(self.data, indexes), labels=labels)
 
     def groupby(self, by: Union[str, Collection]) -> Group:
-        return Group([(value, Table(data)) for value, data in groupby(self.data, by)], by)
+        return Group([(value, Table(data)) for value, data in tim.groupby(self.data, by)], by)
 
     def sum(self) -> dt.RowDict:
-        return sum_data(self.data)
+        return tim.sum_data(self.data)
 
     def count(self) -> dt.RowDict:
-        return count_data(self.data)
+        return tim.count_data(self.data)
 
 
 def read_csv(path: str):
